@@ -1,5 +1,5 @@
-/*-
- * Copyright (c) 1998-2001 Joe marcus Clarke <marcus@marcuscom.com>
+/*, int extendedCommands-
+ * Copyright (c) 1998-2003 Joe Marcus Clarke <marcus@marcuscom.com>
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
@@ -24,6 +24,8 @@
  * SUCH DAMAGE.
  *
  * Gone - a terminal locking program with many improvements over lock(1)
+ *
+ * $Id: gone.c,v 1.3 2003/10/13 05:58:59 marcus Exp $
  */
 
 #include <stdlib.h> /*  atoi() */
@@ -82,30 +84,31 @@ struct timeval  zerotime = {0, 0};
 struct timeval timeout;
 struct timeval zerotime;
 #endif /* OSF1 || ULTRIX */
-#define SALT "3C"
+#define SALT "3C" /* XXX Crappy */
 struct stat ttystat;
 long nexttime;
 mode_t ttymode;
 char *ttynam;
 
 /*  Function prototypes */
-void lockTerm(char *ap, char *password, int timeAway);
+void lockTerm(char *ap, char *password, int timeAway,
+              int extendedCommands, int printBanner);
 char *getPassword();
 void usage(char *progName);
 void quit();
 int hi();
-void printHeader();
+void printHeader(int extendedCommands, int printBanner);
 void print_version_info(void);
 
 struct gone_commands commands[] =
     {
-        "w", "Print a summary of current system activity",
-        "finger", "Display user information",
-        "whoami", "Display the the locking user's name",
-        "help", "Print this message",
-        "date", "Display the dateand time",
-        "status", "Display the lock timeout",
-        "cls", "Clear the screen, and display this message"
+        "w", "Print a summary of current system activity", 1,
+        "finger", "Display user information", 1,
+        "whoami", "Display the the locking user's name", 1,
+        "help", "Print this message", 0,
+        "date", "Display the date and time", 1,
+        "status", "Display the lock timeout", 0,
+        "cls", "Clear the screen, and display this message", 0
     };
 
 #if defined(ULTRIX)
@@ -128,19 +131,24 @@ main(int argc, char *argv[]) {
     int i;
     int mesgOff = 1;
     int useSysPasswd = 0;
+    int extendedCommands = 1;
+    int printBanner = 1;
     char *sysPass;
     struct passwd *pw;
 
     goneTime = TIMEOUT;
 #if defined(OSF1) && defined(EN_SEC) && defined(SETUID)
     set_auth_parameters();
-    while ((ch = getopt(argc, argv, "vpynt:")) != -1)
+    while ((ch = getopt(argc, argv, "bvpxynt:")) != -1)
 #elif defined(SETUID)
-    while ((ch = getopt(argc, argv, "vpynt:")) != -1)
+    while ((ch = getopt(argc, argv, "bvpxynt:")) != -1)
 #else /* OSF1 && EN_SEC && SETUID */
-    while ((ch = getopt(argc, argv, "vynt:")) != -1)
+    while ((ch = getopt(argc, argv, "bvyxnt:")) != -1)
 #endif /* OSF1 && EN_SEC && SETUID */
         switch((char)ch) {
+        case 'b':
+            printBanner = 0;
+            break;
         case 'v':
             print_version_info();
             exit(0);
@@ -168,6 +176,9 @@ main(int argc, char *argv[]) {
             break;
 #endif /* OSF1 && EN_SEC && SETUID */
         case 'n':
+        case 'x':
+            extendedCommands = 0;
+            break;
         case 'y':
             mesgOff = 0;
             break;
@@ -276,12 +287,13 @@ main(int argc, char *argv[]) {
     signal(SIGTSTP, (void (*)(int))hi);
     signal(SIGALRM, (void (*)(int))quit);
     signal(SIGHUP, (void (*)(int))quit);
-    lockTerm(ap, enteredPass, goneTime);
+    lockTerm(ap, enteredPass, goneTime, extendedCommands, printBanner);
 
     return 0;
 }
 
-void lockTerm(char *ap, char *password, int timeAway) {
+void lockTerm(char *ap, char *password, int timeAway,
+              int extendedCommands, int printBanner) {
     char key[PASSWORD_BUFFER];
     char *cryptKey;
     char cmd[BUFSIZ];
@@ -297,7 +309,7 @@ void lockTerm(char *ap, char *password, int timeAway) {
         printf("Terminal locked at %s for %d minutes(s).\n", ap, timeAway);
     }
 
-    printHeader();
+    printHeader(extendedCommands, printBanner);
     fflush(stdin);
     printf("> ");
 
@@ -310,16 +322,16 @@ void lockTerm(char *ap, char *password, int timeAway) {
         goodCommand = 0;
         cmd[strlen(cmd) - 1] = '\0';
         if (!strncmp(cmd, "help",strlen(cmd)) && cmd[0] != '\0') {
-            printHeader();
+            printHeader(extendedCommands, printBanner);
         }
         else if (!strncmp(cmd, "cls", strlen(cmd)) && cmd[0] != '\0') {
             system("clear");
-            printHeader();
+            printHeader(extendedCommands, printBanner);
         }
         else if (!strncmp(cmd, "status", strlen(cmd)) && cmd[0] != '\0') {
             hi();
         }
-        else if (!strncmp(cmd, "finger", strlen(cmd)) && cmd[0] != '\0') {
+        else if (!strncmp(cmd, "finger", strlen(cmd)) && extendedCommands && cmd[0] != '\0') {
             char fingerCommand[BUFSIZ] = "finger ";
             char hostname[BUFSIZ] = "\0";
             char parsedHostname[BUFSIZ] = "\0";
@@ -338,13 +350,13 @@ void lockTerm(char *ap, char *password, int timeAway) {
 
         else {
             for (i = 0; i < sizeof(commands)/sizeof(commands[0]); i++) {
-                if (!strncmp(cmd, commands[i].command, strlen(cmd)) && cmd[0] != '\0') {
+                if (!strncmp(cmd, commands[i].command, strlen(cmd)) && extendedCommands && cmd[0] != '\0') {
                     system(commands[i].command);
                     goodCommand = 1;
                 }
             }
         }
-        if (!goodCommand && strncmp(cmd, "unlock",strlen(cmd)) && strcmp(cmd, "") && strncmp(cmd, "help",strlen(cmd)) && strncmp(cmd, "cls",strlen(cmd)) && strncmp(cmd, "finger",strlen(cmd)) && strncmp(cmd, "status", strlen(cmd))) {
+        if (!goodCommand && strncmp(cmd, "unlock",strlen(cmd)) && strcmp(cmd, "") && strncmp(cmd, "help",strlen(cmd)) && strncmp(cmd, "cls",strlen(cmd)) && (!extendedCommands || strncmp(cmd, "finger",strlen(cmd))) && strncmp(cmd, "status", strlen(cmd))) {
             printf("%s: command not allowed in lock mode\n", cmd);
             printf("Type 'help' for a list of commands.\n");
         }
@@ -371,9 +383,9 @@ void lockTerm(char *ap, char *password, int timeAway) {
 
 void usage(char *progName) {
 #ifdef SETUID
-    printf("Usage: %s [-v] [-p] [-y] [-t timeout] [Gone message]\n", progName);
+    printf("Usage: %s [-v] [-p] [-x] [-y] [-t timeout] [Gone message]\n", progName);
 #else /* SETUID */
-    printf("Usage: %s [-v] [-y] [-t timeout] [Gone message]\n", progName);
+    printf("Usage: %s [-v] [-x] [-y] [-t timeout] [Gone message]\n", progName);
 #endif /* SETUID */
     exit(1);
 }
@@ -384,22 +396,26 @@ void quit() {  /*  log users out by killing their shell */
 }
 
 
-void printHeader() {
+void printHeader(int extendedCommands, int printBanner) {
     int i;
 
-    printf("\n\n\n");
-    printf("                   XXXXX  XX    X        X    X  XXXXX  XXXXX\n");
-    printf("                     X    X X   X        X    X  X      X\n");
-    printf("                     X    X  X  X        X    X  XXXXX  XXX\n");
-    printf("                     X    X   X X        X    X      X  X\n");
-    printf("                   XXXXX  X    XX        XXXXXX  XXXXX  XXXXX\n");
+    if (printBanner) {
+        printf("\n\n\n");
+        printf("                   XXXXX  XX    X        X    X  XXXXX  XXXXX\n");
+        printf("                     X    X X   X        X    X  X      X\n");
+        printf("                     X    X  X  X        X    X  XXXXX  XXX\n");
+        printf("                     X    X   X X        X    X      X  X\n");
+        printf("                   XXXXX  X    XX        XXXXXX  XXXXX  XXXXX\n");
+    }
     printf("\n");
 
     printf("Available commands: \n");
     for(i = 0; i < sizeof(commands)/sizeof(commands[0]); i++) {
-        printf("\t%-8s : %s\n", commands[i].command, commands[i].help_str);
+        if (extendedCommands || !commands[i].extended) {
+            printf("\t%-8s : %s\n", commands[i].command, commands[i].help_str);
+        }
     }
-    printf("\n\tunlock to unlock the terminal\n\n");
+    printf("\n\tType unlock to unlock the terminal\n\n");
 }
 
 hi() {
@@ -435,6 +451,6 @@ void print_version_info(void) {
 #if defined(OSF1) && (EN_SEC) 
     printf("\t* Gone is OSF/1 Enhanced Security-aware.\n");
 #endif /* OSF1 && EN_SEC */
-    printf("\t* Gone copyright MarcusCom 1998-2001.\n");
+    printf("\t* Gone copyright MarcusCom 1998-2003.\n");
 }
 
